@@ -4,15 +4,13 @@ module Types (
   Mirror(..),
   Natural,
   RepoSource(..),
-  Channel(..),
-  channel,
   Verbosity(..),
   Release(..),
   eitherRelease
   ) where
 
 import Data.Char (isDigit)
-import Data.List.Extra (lower)
+import Data.List.Extra (lower, unsnoc)
 import Numeric.Natural
 
 --import Distribution.Fedora.Repoquery
@@ -24,23 +22,11 @@ data Mirror = DownloadFpo | DlFpo | Mirror String
   deriving Eq
 
 -- FIXME: True for koji make into type
-data RepoSource = RepoSource Bool Channel Mirror
+data RepoSource = RepoSource Bool Mirror
   deriving Eq
 
-data Channel = ChanDevel | ChanTest | ChanProd
-  deriving Eq
-
-channel :: Channel -> String
-channel ChanDevel = "development"
-channel ChanTest = "test"
-channel ChanProd = "production"
-
-instance Show Channel where
-  show ChanDevel = "devel"
-  show ChanTest = "test"
-  show ChanProd = "prod"
-
-data Release = EPEL Natural | EPELNext Natural | Centos Natural | Fedora Natural
+data Release = EPEL10Dot Natural | EPEL Natural | EPELNext Natural
+             | Centos Natural | Fedora Natural
              | ELN | Rawhide | System
   deriving (Eq, Ord)
 
@@ -57,9 +43,21 @@ eitherRelease rel =
     -- FIXME add proper parsing:
     "epel8-next" -> Right $ EPELNext 8
     "epel9-next" -> Right $ EPELNext 9
+    ('e':'p':'e':'l':'1':'0':'.':n@(_:_)) | all isDigit n -> let br = EPEL10Dot (read n)
+                                                 in Right br
     ('e':'p':'e':'l':n@(_:_)) | all isDigit n -> let br = EPEL (read n)
                                                  in Right br
-    ('c':n@(_:_)) | all isDigit n -> let r = read n in Right (Centos r)
+    ('c':n@(_:_)) ->
+      let ver =
+            case unsnoc n of
+              Just (v,'s') -> v
+              _ -> n
+      in if null ver
+         then Left rel
+         else
+           if all isDigit ver
+           then Right (Centos $ read ver)
+           else Left rel
     "eln" -> Right ELN
     ('f':n@(_:_)) | all isDigit n -> let r = read n in Right (Fedora r)
     ns@(_:_) | all isDigit ns ->
@@ -74,6 +72,7 @@ eitherRelease rel =
 instance Show Release where
   show Rawhide = "rawhide"
   show (Fedora n) = "f" ++ show n
+  show (EPEL10Dot n) = "epel10." ++ show n
   show (EPEL n) = (if n <= 6 then "el" else "epel") ++ show n
   show (EPELNext n) = "epel" ++ show n ++ "-next"
   show ELN = "eln"
